pub fn is_oneshot(output: &ListOutput) -> boolExpand description
Whether a unit is a oneshot service.
The varlink equivalent of units::is_oneshot_service_by_name, which the
varlink path previously had to reach back to D-Bus for.
pub fn is_oneshot(output: &ListOutput) -> boolWhether a unit is a oneshot service.
The varlink equivalent of units::is_oneshot_service_by_name, which the
varlink path previously had to reach back to D-Bus for.